#
# spec file for package espeak
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           espeak
Version:        1.43.03
Release:        5.6.1
%define _version %{version}-source
License:        GPLv3+
Summary:        Software speech synthesizer (text-to-speech)
Url:            http://espeak.sourceforge.net
Group:          Productivity/Other
Source:         %{name}-%{_version}.tar.bz2
Source1:        espeak.1
# PATCH-FIX-UPSTREAM espeak-audio-runtime-detection.patch vuntz@opensuse.org -- Taken from Fedora
Patch0:         espeak-audio-runtime-detection.patch
# PATCH-FIX-SUSE espeak-volume-full-fix.diff tiwai@suse.de -- Fix full-volume with PulseAudio (bnc#679975)
Patch1:         espeak-volume-full-fix.diff
BuildRequires:  gcc-c++
BuildRequires:  portaudio-devel
BuildRequires:  pulseaudio-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
eSpeak is a compact open source software speech synthesizer for English
and other languages.

eSpeak uses a "formant synthesis" method. This allows many languages to
be provided in a small size. The speech is clear, and can be used at
high speeds, but is not as natural or smooth as larger synthesizers
which are based on human speech recordings.

%package devel
License:        GPLv3+
Summary:        Software speech synthesizer (text-to-speech) -- Development Files
Group:          Productivity/Other
Requires:       espeak

%description devel
eSpeak is a compact open source software speech synthesizer for English
and other languages.

eSpeak uses a "formant synthesis" method. This allows many languages to
be provided in a small size. The speech is clear, and can be used at
high speeds, but is not as natural or smooth as larger synthesizers
which are based on human speech recordings.

%prep
%setup -q -n %{name}-%{_version}
%patch0 -p1
%patch1 -p1
# Don't use the included binary voice dictionaries; we compile these from
# source
%{__rm} espeak-data/*_dict
# Build against portaudio v19 (see ReadMe)
%{__cp} -f src/portaudio19.h src/portaudio.h

%build
cd src
make %{?_smp_mflags} CFLAGS="%{optflags}"
cd ..
# Build the TTS voice dictionaries
export ESPEAK_DATA_PATH=%{_builddir}/%{name}-%{_version}
cd dictsource
for voice in $(../src/speak --voices | awk '{print $2}{print $5}' | egrep -v Language\|File\|/ | uniq); do
    ../src/speak --compile=$voice;
done

%install
cd src
make LIBDIR=%{_libdir} DESTDIR=%{buildroot} install
cd ..
# Remove static libraries
%{__rm} %{buildroot}%{_libdir}/*.a
# Install manpage
%{__install} -D -m 0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/espeak.1
# Rename docs subdir for installation with %doc
%{__mv} docs/ html/

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr (-,root,root,755)
%doc ChangeLog License.txt ReadMe html/
%{_bindir}/espeak
%{_libdir}/libespeak.so.*
%{_datadir}/espeak-data/
%doc %{_mandir}/man1/espeak.1.*

%files devel
%defattr (-,root,root,755)
%{_includedir}/espeak/
%{_libdir}/libespeak.so

%changelog
* Tue Mar 22 2011 tiwai@suse.de
- Fix full-volume reset problem with PulseAudio (bnc#679975)
* Wed Apr  7 2010 vuntz@opensuse.org
- Update to version 1.43.03:
  + Fix crash when embedded control codes are followed by numbers
    of 5 or more digits.
  + Fix lang=hu,  First character of an abbreviation is missed
    after an ordinal number (eg."2. cd")
  + Fix XML tag not recognized after "..." when announce
    punctuation is enabled.
  + Fix lang=zh-yue, 'p' 't' 'k' after a vowel give a long pause.
  + Fix lang=ru, "o" missing in unstressed syllables.
- Changes from version 1.43.02:
  + Language improvements including Danish.
  + Fix: "  50000" with leading spaces was spoken as "50".
  + Don't consider multiple spaces as a thousands separator
    (eg. "2  000").
  + Fixed phoneme [n^] for klatt synthesizer.
  + Lang=Hungarian, don't allow dot as thousands separator.
- Changes from version 1.43:
  + New format for phoneme definitions, including conditional
    statements for more flexibility.
  + Added voice variants which use the Klatt synthesizer rather
    than the eSpeak synthesizer: klatt, klatt2, klatt3
  + Fixes to the Klatt synthesizer.
  + Updated phoneme data for use in the Klatt synthesizer.
  + Allow optional .txt filename suffix for *_rules and *_list
    files.
  + HTML tags should not insert a space when they are removed.
    This could cause a break inside a word (eg. <b>, <font>).
  + Fixes to correctly recognise space as a thousands separator in
    some languages.
- Changes from version 1.42:
  + Improvements to languages including Hungarian, Portuguese,
    Tamil
  + Changes to intonation when announcing punctuation (--punct
    option).
  + Recognise key names in <say-as interpret-as="tts:key"> and
    allow translation into the current language.
  + *_list files, added attribute $hasdot for abbreviations. The
    rule only applies if the word is followed by a dot.
  + SSML (as used by Speech Dispatcher), fix problems where a tag
    after a dot meant that end-of-sentence and ordinal numbers were
    not recognized correctly.
- Changes from version 1.41:
  + Added language: da Danish
  + Language: it Italian, added dictsource/it_listx with data for
    stress positions and open/close "e" and "o" vowels.
  + Languages: pt, it: Fixed a crash when speaking some numbers.
  + Fixed numbers greater than 1000000 for Indian languages.
  + -m option now ignores XML comments.
  + -b option now has a value (4) to specify 16 bit character input
    text.
  + -g option (word gap) fixed for Windows.
  + --punct option. Fix some unnecessary pauses when speaking
    punctuation names.
  + SSML: fixed bug where <mark> was ignored before some
    punctuation characters.
  + Changed the format of formant data in espeak-data/phondata, to
    add extra parameters for use by a Klatt synthesizer. Changed
    the formant dialogue in espeakedit to include these.
  + F7 and F8 formants are now fixed at 7800Hz and 90000Hz.
  + "Text position" in callback events is no longer limited to 16
    bits.
  + Fixed problems with word-length indications in callback events.
  + Some changes to allow compilation on WinCE/Windows Mobile, with
    notes in platforms/windowsMobile.
  + *_list files:
  - Add feature for ordinal numbers (for some languages).
  - Allow hyphenated word groups to start with a number.
  - Allow "words" of symbols to contain brackets.
- Changes from version 1.40:
  + Added languages: lv Latvian, ca Catalan, sq Albanian, hy
    Armenian.
  + Adjusted the tonal quality of the speech to reduce the
    harshness slightly.
  + Language improvements include: English/US, Esperanto.
  + Windows SAPI5 installer: Remove the limit on the number of
    eSpeak voices which can be installed.
  + -m command option: Ignore text within <script> and <style> tag
    pairs.
  + -v command option: If the parameter is not a voice file name,
    look it up as a language name (specified inside voice files).
  + Added command option --path. Specified the path of the
    espeak-data directory.
  + Added command option --phonout. Specifies output of mbrola
    phoneme data, and phoneme data from -x and -X command options,
    to a file rather than stdout.
  + Implemented visemes on the SAPI5 interface.
  + Fix some sound channel lock-ups.
  + Reduced pause when announcing punctuation characters.
  + Add voice variant: "fast" to allow experimentation with faster
    speaking speeds.
  + Removed the use of C++ Classes.
- Drop Makefile.patch: fixed upstream.
- Add espeak-audio-runtime-detection.patch, taken from Fedora, to
  detect at runtime which audio backend to use.
- Add manpage, taken from Ubuntu.
- Build the TTS voice dictionaries instead of shipping the included
  binary ones. This is based on the Fedora packaging.
- Make sure we build against portaudio 19.
- Remove unneeded BuildRequires: jack, jack-devel, portaudio.
- Remove unneeded PreReq on insserv.
- Remove unneeded Requires of devel package: portaudio.
- Remove static libraries.
- Call ldconfig in %%post/%%postun.
- Improve package description.
* Fri Feb  5 2010 embar@users.berlios.de
- fixed bug #549899
  (enabled portaudio support and disabled pulseaudio)
* Mon Oct 13 2008 marco@suse.de
- enabled pulseaudio support and disabled portaudio
* Thu Sep 11 2008 marco@suse.de
- updated to 1.39
- split the package in espeak and espeak-devel
* Fri Feb 15 2008 marco@suse.de
- updated to 1.31.11
* Fri Feb 15 2008 marco@suse.de
- updated to 1.31
  Tue Jan  8 20:05:57 CET 2008
- added compiler option -Wno-variadic-macros to avoid build errors
  Tue Jan  8 14:23:20 CET 2008
- updated to espeak 1.30
* Mon Jul 23 2007 marco@suse.de
- fixed build-prblems for x86_64
- added LIBDIR variable to Makefile
